# Copyright (C) 2021 Associated Universities, Inc. Washington DC, USA.
#
# This file is part of NRAO Workspaces.
#
# Workspaces is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Workspaces is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
"""add created/updated timestamps to capability executions

Revision ID: a3b9fdce74bd
Revises: c3e0d50b5189
Create Date: 2021-03-23 10:13:22.463607

"""
import sqlalchemy as sa
from alembic import op

# revision identifiers, used by Alembic.
revision = "a3b9fdce74bd"
down_revision = "c3e0d50b5189"
branch_labels = None
depends_on = None


def upgrade():
    op.add_column(
        "capability_executions",
        sa.Column(
            "created_at",
            sa.DateTime(timezone=True),
            server_default=sa.func.now(),
            nullable=False,
        ),
    )
    op.add_column(
        "capability_executions",
        sa.Column(
            "updated_at",
            sa.DateTime(timezone=True),
            server_default=sa.func.now(),
            nullable=False,
        ),
    )

    op.execute(
        """
    create trigger capability_execution_updated
    before update on capability_executions
    for each row execute procedure update_updated_at_timestamp();"""
    )


def downgrade():
    op.drop_column("capability_executions", "created_at")
    op.drop_column("capability_executions", "updated_at")
    op.execute("drop trigger capability_execution_updated on workflow_requests")
